import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n

import "../widgets"
import "../core"

ModalForm {
    id: root
    Style.class: "addBagForm"

    implicitWidth: 735
    implicitHeight: content.implicitHeight + topPadding + bottomPadding

    ColumnLayout {
        id: content
        anchors.left: parent.left
        anchors.right: parent.right
        SLabel {
            Layout.fillWidth: true
            Style.class: "addBagTitle"
            Tr { code: "addBagTitle" }
            horizontalAlignment: Text.AlignHCenter
        }
        Space { height: 80 }
        Item {
            id: bags
            Layout.preferredWidth: 300 * model.columns + spacing * (model.columns - 1)
            Layout.preferredHeight: {
                if (itemHeightForRow === undefined)
                    return 0
                let itemsHeight = 0
                for (let i = 0; i < itemHeightForRow.length; ++i)
                    itemsHeight += itemHeightForRow[i]
                return itemsHeight + spacing * (model.rows - 1)
            }
            Layout.alignment: Qt.AlignHCenter
            property BagsInfoModel model: BagsInfoModel {}
            property var itemHeightForRow
            property real itemWidth: 300
            property real spacing: 20
            property var bagsAdded

            Repeater {
                model: bags.model

                Item {
                    width: bags.itemWidth * model.rowSpan + bags.spacingCorrection(model.row)
                    height: bags.itemHeightForRow ? bags.itemHeightForRow[model.row] : 0
                    x: bags.getX(model.row, model.column, model.rowSpan)
                    y: bags.getY(model.row)

                    ColumnLayout {
                        id: itemContent
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.bottom: parent.bottom
                        onImplicitHeightChanged: {
                            bags.initItemHeights()
                            let newList = bags.itemHeightForRow
                            if (implicitHeight > bags.itemHeightForRow[model.row])
                                newList[model.row] = implicitHeight
                            bags.itemHeightForRow = newList
                        }
                        Space { height: bags.maxImgHeight - model.iconHeight }
                        Item {
                            height: model.iconHeight
                            Layout.fillWidth: true
                            SvgImage {
                                anchors.fill: parent
                                source: Style.parameter(model.icon)
                            }
                        }
                        Space { height: 20 }
                        SLabel {
                            Layout.preferredWidth: bags.itemWidth
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "addBagItemName"
                            Tr { code: model.name }
                            horizontalAlignment: Text.AlignHCenter
                        }
                        Space { height: 20 }
                        SLabel {
                            Layout.preferredWidth: bags.itemWidth
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "addBagItemInfo"
                            Tr {
                                property bool withDef: model.defCount > 0
                                code: withDef ? "addBagMsgWithCount" : "addBagMsg"
                                args: withDef ? [ model.price, model.defCount ] : [ model.price ]
                            }
                            horizontalAlignment: Text.AlignHCenter
                        }
                        Space { height: 60 }
                        RowLayout {
                            Layout.alignment: Qt.AlignHCenter
                            spacing: 20
                            ActionButton {
                                Layout.preferredWidth: 80
                                Layout.preferredHeight: 80
                                Style.class: "addBagMinus"
                                enabled: input.value > 0
                                iconAntialiasing: false
                                icon: enabled ? Style.parameter("icon.addBagFrom.minus")
                                              : Style.parameter("icon.addBagFrom.minus_disable")
                                onClicked: input.value--
                            }
                            SGroupBox {
                                Layout.preferredWidth: 100
                                Layout.preferredHeight: 80
                                Style.class: "addBagInputField"
                                STextEdit {
                                    anchors.centerIn: parent
                                    id: input
                                    property int value: 0
                                    enabled: false
                                    Style.class: "addBagInputField"
                                    text: (value + model.defCount)
                                    onValueChanged: bags.updateBagsAdded(index, value)
                                    Connections {
                                        target: bags
                                        function onBagsAddedChanged() {
                                            if (bags.bagsAdded && bags.bagsAdded[index])
                                                input.value = bags.bagsAdded[index]
                                        }
                                    }
                                }
                            }
                            ActionButton {
                                Layout.preferredWidth: 80
                                Layout.preferredHeight: 80
                                Style.class: "addBagPlus"
                                iconAntialiasing: false
                                icon: Style.parameter("icon.addBagFrom.plus")
                                onClicked: input.value++
                            }
                        }
                    }
                }
            }
            // Определить относительные координаты элемента по оси X
            function getX(row, column, span) {
                return (itemWidth * span + spacingCorrection(row) + spacing) * column
            }
            // Определить относительные координаты элемента по оси Y
            function getY(row) { return row ? (itemHeightForRow[row - 1] + spacing) * row : 0 }
            // Корректировка для ширины и X координаты на случай несовпадения количества столбцов в строках
            function spacingCorrection(row) {
                let cols = model.columnsForRow(row)
                return (model.columns - cols) * spacing / cols
            }
            // Инициализировать список высот для элементов
            function initItemHeights() {
                if (itemHeightForRow !== undefined)
                    return
                let newList = []
                for (let i = 0; i < model.rows; ++i)
                    newList.push(0)
                itemHeightForRow = newList
            }
            // Обновить количество добавляемых пакетов
            function updateBagsAdded(index, value) {
                let newMap = bagsAdded ? bagsAdded : {}
                if (newMap[index] === value)
                    return
                newMap[index] = value
                bagsAdded = newMap
            }
        }
        Space { height: 20 }
        ActionButton {
            Layout.fillWidth: true
            Layout.preferredHeight: 110
            Style.class: "addBagOk"
            Tr { code: "addBagConfirmOk" }
            enabled: {
                if (bags.bagsAdded === undefined)
                    return false
                for (let key in bags.bagsAdded)
                    if (bags.bagsAdded[key] > 0)
                        return true
                return false
            }
            onClicked: {
                Check.updateBagsInfos(bags.bagsAdded)
                removeContext()
            }
        }
        Space { height: 20 }
        ActionButton {
            Layout.fillWidth: true
            Layout.preferredHeight: 110
            Style.class: "addBagCancel"
            icon: Style.parameter("icon.addBagFrom.cancel")
            Tr { code: "addBagConfirmCancel" }
            onClicked: removeContext()
        }
    }
}
