import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "bankCardForm"

    SGroupBox {
        anchors.fill: parent
        ColumnLayout {
            anchors.centerIn: parent
            SLabel {
                Layout.alignment: Qt.AlignHCenter
                Style.class: "bankCardTitle"
                Tr { code: "bankCardTitle" }
            }
            Space { height: 40 }
            SLabel {
                Layout.alignment: Qt.AlignHCenter
                Style.class: "bankCardMsg"
                Tr { code: "bankCardMsg" }
            }
            Space { height: 180 }
            SvgImage {
                Layout.alignment: Qt.AlignHCenter
                source: Style.parameter("image.paymentTerminal")
                SvgImage {
                    id: success
                    property real baseDuration: Style.animationDuration("bankCard", 600)
                    x: 190; y: 80
                    source: Style.parameter("image.paymentCardSuccess")
                    state: timer.currentState
                    states: [
                        State {
                            name: "start"
                            PropertyChanges { target: success; opacity: 0; scale: 0 }
                        },
                        State {
                            name: "finish"
                            PropertyChanges { target: success; opacity: 1; scale: 1 }
                        }
                    ]
                    transitions: [
                        Transition {
                            from: "start"; to: "finish"
                            NumberAnimation {
                                property: "scale"; easing.type: Easing.InQuad; duration: success.baseDuration
                            }
                            NumberAnimation { property: "opacity"; duration: success.baseDuration }
                        },
                        Transition {
                            from: "finish"; to: "start"
                            NumberAnimation {
                                property: "scale"; easing.type: Easing.OutQuad; duration: success.baseDuration
                            }
                            NumberAnimation { property: "opacity"; duration: success.baseDuration }
                        }
                    ]
                }
                SvgImage {
                    id: hand
                    property real baseVelocity: Style.animationVelocity("bankCard", 200)
                    source: Style.parameter("image.paymentHand")
                    state: timer.currentState
                    states: [
                        State {
                            name: "start"
                            PropertyChanges { target: hand; y: 205; x: 270 }
                        },
                        State {
                            name: "finish"
                            PropertyChanges { target: hand; y: 73; x: 360; rotation: 32 }
                        }

                    ]
                    transitions: Transition {
                        SmoothedAnimation { properties: "y"; velocity: hand.baseVelocity }
                        SmoothedAnimation { properties: "x"; velocity: hand.baseVelocity * 0.68 }
                        SmoothedAnimation { properties: "rotation"; velocity: hand.baseVelocity * 0.24 }
                    }
                }
                Timer {
                    id: timer
                    property string currentState: "start"
                    interval: Style.animationDuration("bankCard", 3000)
                    running: true
                    triggeredOnStart: true
                    repeat: true
                    onTriggered: {
                        if (currentState == "start")
                            currentState = "finish"
                        else
                            currentState = "start"
                    }
                }
            }
        }
    }
}
