import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Dialog
import I18n

import "../core"
import "../widgets"

BaseForm {
    Style.class: "closingForm"

    SGroupBox {
        anchors.fill: parent
        ColumnLayout {
            anchors.horizontalCenter: parent.horizontalCenter
            y: 290
            spacing: 220
            SLabel {
                Layout.alignment: Qt.AlignHCenter
                Style.class: "closingTitle"
                Tr { code: "closingTitle" }
                horizontalAlignment: Text.AlignHCenter
            }
            BusyIndicator {
                Layout.alignment: Qt.AlignHCenter
                id: indicator
                Layout.preferredHeight: 350
                Layout.preferredWidth: 350
                running: true
                contentItem: Item {
                    id: indicatorContent
                    anchors.fill: parent
                    LayoutMirroring.enabled: true
                    LayoutMirroring.childrenInherit: true
                    property int rotateIndex: 0
                    rotation: 360 / repeater.count * rotateIndex
                    Repeater {
                        id: repeater
                        model: 16
                        delegate: Rectangle {
                            id: element
                            anchors.top: parent.top
                            width: 20
                            height: 70
                            color: Style.color("green")
                            x: indicator.width / 2 - width / 2
                            y: 0
                            radius: width
                            opacity: index ? (index - 1) / repeater.count : 1
                            transform: Rotation {
                                origin.x: width / 2
                                origin.y: indicator.height / 2
                                angle: (360 / repeater.count) * index
                            }
                        }
                    }
                    NumberAnimation on rotateIndex {
                        from: 0
                        to: repeater.count
                        running: indicator.running
                        duration: Style.animationDuration("closing", 1500)
                        loops: Animation.Infinite
                    }
                }
            }
        }
        ColumnLayout {
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            spacing: 40
            SLabel {
                Layout.alignment: Qt.AlignHCenter
                Style.class: "closingProgress"
                Tr { code: "closingProgress" }
            }
            SProgressBar {
                id: progress
                Style.class: "closingProgressBar"

                Layout.preferredWidth: 650
                Layout.preferredHeight: Math.max(10, Style.content.height)

                value: DialogState.newProgressState.progress

                content.width: progress.visualPosition * parent.width
            }
            Space { height: 40 }
        }
    }
}
