import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "payGiftForm"

    Context.inputSources: InputSources.Msr | InputSources.Scanner

    ColumnLayout {
        Layout.fillWidth: true
        anchors.fill: parent
        spacing: 20

        SGroupBox {
            Layout.fillHeight: true
            Layout.fillWidth: true

            ColumnLayout {
                anchors.centerIn: parent
                spacing: 180

                ColumnLayout {
                    spacing: 40
                    Layout.alignment: Qt.AlignHCenter

                    SLabel {
                        Layout.alignment: Qt.AlignHCenter
                        Style.class: "payGiftTitle"
                        Tr { code: "payGiftTitle" }
                    }

                    SLabel {
                        Layout.alignment: Qt.AlignHCenter
                        Style.class: "payGiftMsg"
                        Tr { code: "payGiftMsg" }
                    }
                }

                SvgImage {
                    Layout.alignment: Qt.AlignHCenter
                    source: Style.parameter("image.paymentTerminal")
                    SvgImage {
                        id: success
                        property real baseDuration: Style.animationDuration("payGift", 600)
                        x: 190; y: 80
                        source: Style.parameter("image.paymentGiftSuccess")
                        state: timer.currentState
                        states: [
                            State {
                                name: "start"
                                PropertyChanges { target: success; opacity: 0; scale: 0 }
                            },
                            State {
                                name: "finish"
                                PropertyChanges { target: success; opacity: 1; scale: 1 }
                            }
                        ]
                        transitions: [
                            Transition {
                                from: "start"; to: "finish"
                                NumberAnimation {
                                    property: "scale"; easing.type: Easing.InQuad; duration: success.baseDuration
                                }
                                NumberAnimation { property: "opacity"; duration: success.baseDuration }
                            },
                            Transition {
                                from: "finish"; to: "start"
                                NumberAnimation {
                                    property: "scale"; easing.type: Easing.OutQuad; duration: success.baseDuration
                                }
                                NumberAnimation { property: "opacity"; duration: success.baseDuration }
                            }
                        ]
                    }
                    SvgImage {
                        id: scannerFlash
                        property real baseDuration: Style.animationDuration("payGift", 600)
                        x: 320; y: 485
                        source: Style.parameter("image.paymentTerminalScannerFlash")
                        state: timer.currentState
                        states: [
                            State {
                                name: "start"
                                PropertyChanges { target: scannerFlash; opacity: 0 }
                            },
                            State {
                                name: "finish"
                                PropertyChanges { target: scannerFlash; opacity: 1 }
                            }
                        ]
                        transitions: [
                            Transition {
                                from: "start"; to: "finish"
                                NumberAnimation { property: "opacity"; duration: scannerFlash.baseDuration }
                            },
                            Transition {
                                from: "finish"; to: "start"
                                NumberAnimation { property: "opacity"; duration: scannerFlash.baseDuration }
                            }
                        ]
                    }
                    SvgImage {
                        id: hand
                        property real baseDuration: Style.animationDuration("payGift", 600)
                        source: Style.parameter("image.paymentGiftHand")
                        state: timer.currentState
                        states: [
                            State {
                                name: "start"
                                PropertyChanges { target: hand; y: 650; x: 225; rotation: -11 }
                            },
                            State {
                                name: "finish"
                                PropertyChanges { target: hand; y: 490; x: 275; rotation: 0 }
                            }

                        ]
                        transitions: Transition {
                            NumberAnimation { properties: "y"; duration: hand.baseDuration }
                            NumberAnimation { properties: "x"; duration: hand.baseDuration }
                            NumberAnimation { properties: "rotation"; duration: hand.baseDuration }
                        }
                    }
                    Timer {
                        id: timer
                        property string currentState: "start"
                        interval: Style.animationDuration("payGift", 600) * 5
                        running: true
                        triggeredOnStart: true
                        repeat: true
                        onTriggered: {
                            if (currentState == "start")
                                currentState = "finish"
                            else
                                currentState = "start"
                        }
                    }
                }
            }
        }

        ActionButton {
            Layout.fillWidth: true
            Layout.preferredHeight: 110
            Style.class: "paymentGiftCancel"
            Tr { code: "payGiftCancel" }
            icon: Style.parameter("icon.payment.closeGiftCard")
            onClicked: () => removeContext()
        }
    }
}
