import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    Style.class: "paymentForm"
    focusPolicy: Qt.ClickFocus

    Context.logoActionInfo: true

    ColumnLayout {
        anchors.fill: parent
        spacing: 40
        SGroupBox {
            id: infoBlock
            Layout.fillWidth: true
            Layout.fillHeight: true
            ColumnLayout {
                y: 120
                anchors.horizontalCenter: parent.horizontalCenter
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "paymentTitle"
                    Tr { code: "paymentTitle" }
                }
                Space { height: 30 }
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "paymentHint"
                    Tr { code: Check.due.zero ? "paymentHintPaid" : "paymentHint" }
                }
                Space { height: 60 }
                SvgImage {
                    Layout.alignment: Qt.AlignHCenter
                    source: bonusBlock.visible && couponBlock.visible
                            ? Style.parameter("image.paymentCheckLong")
                            : Style.parameter("image.paymentCheck")
                    ColumnLayout {
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.leftMargin: 50
                        anchors.rightMargin: 50
                        spacing: 20
                        SLabel {
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "paymentDue"
                            Tr { code: "paymentDue" }
                        }
                        SMoney {
                            Layout.alignment: Qt.AlignHCenter
                            visible: !Check.discount.zero
                            Style.class: "paymentTotalNoDiscValue"
                            money: Check.totalNoDisc
                            discount: true
                            color: styleColor
                            backgroundColor: infoBlock.Style.background.color
                        }
                        SMoney {
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "paymentDueValue"
                            money: Check.due
                            color: styleColor
                        }
                        RowLayout {
                            Layout.alignment: Qt.AlignHCenter
                            SLabel {
                                Style.class: "paymentPaid"
                                Tr { code: "paymentPaid" }
                            }
                            SMoney {
                                Style.class: Check.paid.zero ? "paymentPaidZero" : "paymentPaidValue"
                                money: Check.paid
                                color: styleColor
                            }
                        }
                        ColumnLayout {
                            id: bonusBlock
                            visible: !Check.earn.zero
                            Layout.alignment: Qt.AlignHCenter
                            spacing: parent.spacing
                            DashLineSeparator {
                                Layout.fillWidth: true
                                Layout.preferredHeight: strokeWidth
                                strokeWidth: 1
                                dashPattern: [ 10, 10 ]
                                color: Style.color("grayBorder")
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentEarn"
                                Tr { code: "paymentEarn" }
                            }
                            SMoney {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentEarnValue"
                                money: Check.earn
                                color: styleColor
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentEarnHint"
                                Tr { code: "paymentEarnHint" }
                            }
                        }
                        ColumnLayout {
                            id: couponBlock
                            visible: Check.coupon
                            Layout.alignment: Qt.AlignHCenter
                            spacing: parent.spacing
                            DashLineSeparator {
                                Layout.fillWidth: true
                                Layout.preferredHeight: strokeWidth
                                strokeWidth: 1
                                dashPattern: [ 10, 10 ]
                                color: Style.color("grayBorder")
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentCouponTitle"
                                Tr { code: "paymentCouponTitle" }
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentCouponName"
                                text: Check.coupon ? Check.coupon.name : ""
                            }
                            SLabel {
                                property string campaign: Check.coupon ? Check.coupon.campaignName : ""
                                visible: campaign.length > 0
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentCouponMessage"
                                text: campaign
                            }
                        }
                        Space { height: 50 }
                    }
                }
            }
        }
        Item {
            id: paymentButtons
            visible: !Check.due.zero
            Layout.fillWidth: true
            property PaymentMethodsModel paymentModel: PaymentMethodsModel{}
            property real spacing: 20
            property real buttonHeight: 110
            property int rows: paymentModel.buttonRows()
            Layout.preferredHeight: buttonHeight * rows + spacing * (rows - 1)
            Repeater {
                model: paymentButtons.paymentModel
                delegate: ActionButton {
                    enabled: model.available
                    width: paymentButtons.buttonWidth(row)
                    height: paymentButtons.buttonHeight
                    x: paymentButtons.getX(column, width)
                    y: paymentButtons.getY(row)
                    Style.class: model.style
                    icon: model.icon
                    iconSize: !model.name ? 0 : this.iconSize
                    Tr { code: name }

                    action: Action {
                        command: "CHECK_ADDPAYMENT"
                        property int paymentType: model.type
                        property string paymentCode: model.code
                        property int idleTimeout: model.idleTimeout
                    }
                }
            }
            function getX(column, buttonWidth) {
                return (buttonWidth + spacing) * column
            }
            function getY(row) {
                return (buttonHeight + spacing) * row
            }
            function buttonWidth(row) {
                const count = paymentModel.buttonRowCount(row)
                return width / count - spacing * (count - 1) / count
            }
        }

        ActionButton {
            visible: Check.due.zero
            Layout.fillWidth: true
            Layout.preferredHeight: 110
            action: "CHECK_CLOSE"
            Tr { code: "paymentClose" }
        }

        ActionButton {
            Layout.alignment: Qt.AlignVCenter
            Layout.fillWidth: true
            Layout.preferredHeight: 110
            Style.class: "paymentBackToForming"
            action: "CHECK_BACKTOFORMING"
            Tr { code: "paymentBack" }
            enabled: !Check.due.zero || Config.getBool("Check:backToFormingPaid")
            icon: Style.parameter("icon.payment.backToForming")
        }
    }
}
