import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "welcomeForm"

    Context.context {
        inputSources: InputSources.All
        topPanelColor: Style.color("welcomeBackground")
        logoActionInfo: true
    }

    ColumnLayout {
        anchors.fill: parent
        spacing: 0

        Space {
            height: 80
        }

        SLabel {
            Style.class: "welcomeTitle"
            Tr { code: "welcomeTitle" }
            Layout.alignment: Qt.AlignHCenter
        }

        SLabel {
            Style.class: "welcomeScanBarcode"
            Tr { code: "welcomeScanBarcode" }
            horizontalAlignment: Qt.AlignHCenter
            wrapMode: Text.WordWrap
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: parent.width
        }

        SLabel {
            Style.class: "welcomeOrPressButton"
            Tr { code: "welcomeOrPressButton" }
            horizontalAlignment: Qt.AlignHCenter
            Layout.alignment: Qt.AlignHCenter
        }

        Space {
            height: 30
        }

        ActionButton {
            Style.class: "welcomeStart"
            Tr { code: "welcomeStart" }
            action: "CHECK_START"
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 480
            Layout.preferredHeight: 128
        }

        ActionButton {
            Style.class: "welcomePriceChecker"
            Tr { code: "welcomePriceChecker" }
            action: "PRICECHECKER_SHOW"
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 480
            Layout.preferredHeight: 128
        }

        Space {
            height: 20
        }

        SLabel {
            Style.class: "welcomePaymentListTitle"
            Tr { code: "welcomePayments" }
            horizontalAlignment: Qt.AlignHCenter
            Layout.alignment: Qt.AlignHCenter
        }

        Space {
            height: 30
        }

        Speener {
            id: paymentMethodsList
            Layout.alignment: Qt.AlignHCenter
            Layout.maximumWidth: parent.width
            Layout.preferredWidth: parent.width
            Layout.preferredHeight: 50
            interactive: count > 3
            pathItemCount: 3
            spacing: 80
            contentItemWidth: 200
            currentIndex: count > 2 ? 1 : 0

            property real preferredHighlight: count != 2 ? 0.5 : (2/7)
            preferredHighlightBegin: preferredHighlight
            preferredHighlightEnd: preferredHighlight

            model: PaymentMethodsModel { withDisabled: false }

            IdleMonitor {
                id: autoSpeenTimer
                property real configSeconds: Style.parameter("welcomePaymentMethodsListAutoscrollSeconds", 2)
                property real configManualSeconds: Style.parameter("welcomePaymentMethodsListAutoscrollManualSeconds", 5)
                seconds: configSeconds
                enabled: Context.onTop && paymentMethodsList.count > 3
                onTimeout: () => {
                    seconds = configSeconds
                    paymentMethodsList.currentIndex += 1
                    interrupt()
                }
            }

            onFlickingChanged: () => {
                autoSpeenTimer.seconds = autoSpeenTimer.configManualSeconds
                autoSpeenTimer.interrupt()
            }

            Behavior on offset { NumberAnimation { duration: Style.animationDuration("welcome.autoscroll", 500) } }

            delegate: RowLayout {
                visible: PathView.onPath
                spacing: 20

                /**
                 * _x:   Значение где находится текущий элемент.
                 *       Экспирементальным путем было выяснено что отображаются элементы с 0.5 по 3.5
                 *
                 * _opacity: Не нормализованное значение прозрачности
                 *           Таблица некоторых значений в зависимости от _x:
                 *          | _x  | _opacity |
                 *          |   0 |   -1     |
                 *          | 0.5 |    0     |
                 *          |   1 |    1     |
                 *          |   2 |    3     |
                 *          |   3 |    1     |
                 *          | 3.5 |    0     |
                 *          |   4 |    -1    |
                 */
                property real _x: (model.index + PathView.view.offset + 2) % PathView.view.count
                property real _opacity: _x > 2 ? 7 - 2 * _x : 2 * _x - 1
                opacity: paymentMethodsList.count > 3 ? Math.max(0, Math.min(_opacity, 1)) : 1

                SvgImage {
                    Layout.preferredWidth: 50
                    Layout.preferredHeight: 50
                    source: model.welcomeIcon
                }

                SLabel {
                    Style.class: "welcomePaymentName"
                    Tr { code: model.welcomeName }
                    Layout.preferredWidth: 130
                    wrapMode: Text.WordWrap
                    horizontalAlignment: Qt.AlignLeft
                    verticalAlignment: Qt.AlignVCenter
                }
            }
        }

        Space {
            height: 250
        }
    }

    property real bgMultiplier: 1

    background: WelcomeBackground { multiplier: root.bgMultiplier }

    pushExit: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "bgMultiplier"
                from: 1.0; to: 0.97
                easing.type: Easing.OutQuad
                duration: Style.animationDuration("transition.welcome", 200)
            }
            NumberAnimation {
                target: root; property: "bgMultiplier"
                from: 0.97; to: 2
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.welcome", 600)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 1; to: 0
                easing.type: Easing.OutCubic
                duration: Style.animationDuration("transition.welcome", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "bgMultiplier"; to: 1; duration: 0 }
        NumberAnimation { target: root; property:      "opacity"; to: 1; duration: 0 }
    }
}
