import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Dialog
import I18n
import Check

import "../widgets"
import "../core"
import "../check"

ModalForm {
    id: root
    Style.class: "callAttendantExtForm"

    property var action: DialogState.actions[Context.id.value]
    property int positionsCount: action.positions.length

    Context.inputSources: InputSources.inputSources(action.inputSources)
    Context.context.logoActionInfo: () => this.logoAction()
    allowFloatKeyboard: false   ///< встроенной клавиатуры нет, но есть скрытое поле ввода для физической клавиатуры

    function logoAction() {
        action.input = ""
        removeContext()
    }
    function input() {
        if (password.text.length === 0)
            return
        action.input = password.text
        removeContext()
    }

    Keys.onEnterPressed: () => input()
    Keys.onReturnPressed: () => input()

    ColumnLayout {
        anchors.fill: parent
        TextInput { id: password; visible: false; focus: true }
        SvgImage {
            Layout.alignment: Qt.AlignHCenter
            source: action.image
        }
        Space { height: 40 }
        SLabel {
            Layout.fillWidth: true
            horizontalAlignment: SLabel.AlignHCenter
            wrapMode: SLabel.WordWrap
            Tr { tr: action.title }
            Style.class: "callAttendantExtTitle"
        }
        Space { height: 40 }
        SLabel {
            Layout.fillWidth: true
            horizontalAlignment: SLabel.AlignHCenter
            wrapMode: SLabel.WordWrap
            Tr { tr: action.message }
            Style.class: "callAttendantExtMessage"
        }
        Space { height: 40 }
        PositionList {
            id: positionList
            property real delegateHeight: 100
            interactive: false
            Layout.fillWidth: true
            Layout.preferredHeight: delegateHeight * Math.min(model.count, 6)
                                    + Math.min(model.count, 6) + 1 // Разделители
            CheckModel { id: sourceModel  }
            model: FilterModel {
                id: model
                sourceModel: sourceModel
                filterFunction: (pos) => action.positions.some((id) => id === pos.posId)
                                         && action.positions.indexOf(pos.posId) < 6
            }
            delegate: ColumnLayout {
                width: positionList.width
                height: positionList.delegateHeight
                DashLineSeparator {
                    Layout.fillWidth: true; Layout.alignment: Qt.AlignTop; visible: !index
                    dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                }
                RowLayout {
                    Layout.fillWidth: true; Layout.alignment: Qt.AlignVCenter
                    Space { width: 10 }
                    SLabel {
                        Layout.fillWidth: true
                        Style.class: "callAttendantExtPositionName"
                        text: model.name
                        elide: Text.ElideRight
                    }
                    Space { width: 20 }
                    SLabel {
                        leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                        Style.class: "callAttendantExtPositionQuantity"
                        text: "x" + model.quantity.str
                    }
                    Space { width: 10 }
                }
                DashLineSeparator {
                    Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom
                    dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                }
            }
        }
        Space { height: 40; visible: positionsCount - 6 > 0 }
        SLabel {
            Layout.fillWidth: true
            horizontalAlignment: SLabel.AlignHCenter
            visible: positionsCount - 6 > 0
            Tr { code: "attendantExtManyItems"; args: [ (positionsCount - 6) ] }
            Style.class: "callAttendantExtMessage"
        }
        Space { height: 40 }
        HelpButton {
            id: help
            Style.class: "callAttendantExtHelpButton"
            iconFixedColor: true
            iconVisible: timerRunning
            seconds: 30

            Tr { code: "attendantExtHelpButton" }

            Layout.fillWidth: true
            Layout.preferredHeight: 105
        }
    }
}
