import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n
import Dialog

import "../core"
import "../widgets"

ModalForm {
    id: root
    Style.class: "productInfoForm"

    property var action: DialogState.actions[Context.id.value]

    function accept() {
        action.add = true
        removeContext()
    }

    function reject() {
        removeContext()
    }

    Keys.onEnterPressed:  () => accept()
    Keys.onEscapePressed: () => reject()
    Keys.onReturnPressed: () => accept()

    ColumnLayout {
        anchors.fill: parent
        spacing: 100

        ColumnLayout {
            spacing: 40

            SLabel {
                id: title
                wrapMode: SLabel.WordWrap
                horizontalAlignment: Text.AlignHCenter
                Style.class: "productInfoTitle"
                Tr { tr: action.title; fallback: "productInfoTitle" }

                Layout.fillWidth: true
            }

            GoodsCard {
                id: card
                product: action.product
                image: action.image

                labelName: "productInfoLabel"
                labelBarcode: "productInfoBarcode"
                moneyPrice: "productInfoPrice"

                Layout.fillWidth: true
            }
        }

        ColumnLayout {
            spacing: 20

            ActionButton {
                id: add
                Style.class: "productInfoAdd"
                Tr { tr: root.action.okButton; fallback: "productInfoAdd" }
                onClicked: () => root.accept()

                Layout.preferredHeight: 105
                Layout.fillWidth: true
            }

            ActionButton {
                id: exit
                icon: Style.parameter("icon.productInfo.cancel")
                Style.class: "productInfoCancel"
                Tr { tr: root.action.cancelButton; fallback: "productInfoCancel" }
                onClicked: () => root.reject()

                Layout.preferredHeight: 105
                Layout.fillWidth: true
            }
        }
    }
}
