import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n
import PickList as PL

import "../core"
import "../picklist"
import "../widgets"

ModalForm {
    id: root
    Style.class: "pickListForm"

    anchors.fill: parent
    implicitWidth: content.implicitWidth
    implicitHeight: content.implicitHeight

    allowFloatKeyboard: true

    // Сигнал закрытия клавиатуры. Прокидывается в Application.qml
    signal hideKeyboard()

    Control {
        id: content

        implicitWidth: 1080 - Layout.leftMargin - Layout.rightMargin
        implicitHeight: 1776 - Layout.topMargin - Layout.bottomMargin

        Layout.margins: 76
        Layout.bottomMargin: 84
        Layout.topMargin: 80
        anchors.fill: parent

        contentItem: ColumnLayout {
            spacing: 36

            SGroupBox {
                padding: 5

                contentItem: PickList {
                    id: pickList
                    grid: Qt.size(4, 6)

                    onHideKeyboard: root.hideKeyboard()

                    Action {
                        id: action
                        command: "PICKLIST_SELECT"
                        property var item

                        onSuccess: () => modalPickList.accept()
                    }

                    onSelected: (index) => {
                        action.item = PL.PickList.pageModel.modelItem(index)
                        action.exec()
                    }
                }

                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            ActionButton {
                id: closeModalPickList
                Style.class: "outlined"
                visible: PL.PickList.canCloseDialog

                icon: Style.parameter("icon.pickList.close")
                Tr { code: "pickListClose" }

                onClicked: () => {
                    pickList.clearFilter()
                    PL.PickList.pageModel.reset()
                    removeContext()
                }

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }
        }
    }
}
