import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n
import WeightControl

import "../check"
import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "weightControlErrorForm"
    focusPolicy: Qt.ClickFocus

    Context.logoActionInfo: "WEIGHTCONTROL_ERRORAUTH"

    property int error: WeightControl.error
    property bool heft: error === WeightControlTypes.NotAdded && WeightControl.errorCanBeCanceled

    ColumnLayout {
        Layout.fillWidth: true
        anchors.fill: parent
        spacing: 20

        SGroupBox {
            Layout.fillWidth: true
            Layout.fillHeight: true

            ColumnLayout {
                anchors.centerIn: parent
                anchors {
                    right: parent.right
                    left: parent.left
                }

                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: parent.width
                    horizontalAlignment: Text.AlignHCenter
                    Style.class: "weightControlErrorTitle"
                    wrapMode: SLabel.WordWrap
                    Layout.fillWidth: true

                    Tr {
                        code: {
                            if (root.heft)
                                return "wceHeftTitle"

                            switch(root.error) {
                            case WeightControlTypes.NotAdded: return "wceNotAddedTitle"
                            case WeightControlTypes.NotScanned: return "wceNotScannedTitle"
                            case WeightControlTypes.Overweight: return "wceOverweightTitle"
                            case WeightControlTypes.Removed: return "wceRemovedTitle"
                            case WeightControlTypes.RemovedHeft: return "wceRemovedHeftTitle"
                            case WeightControlTypes.NotStable: return "wceNotStableTitle"
                            case WeightControlTypes.WrongWeight: return "wceWrongWeightTitle"
                            case WeightControlTypes.NotScannedAbuse: return "wceNotScannedAbuseTitle"
                            case WeightControlTypes.NotScannedPay: return "wceNotScannedPayTitle"
                            default: return ""
                            }
                        }
                    }
                }
                Space { height: 50 }
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: parent.width
                    horizontalAlignment: Text.AlignHCenter
                    Style.class: "weightControlErrorHint"
                    wrapMode: SLabel.WordWrap
                    Layout.fillWidth: true

                    Tr {
                        code: {
                            if (root.heft)
                                return WeightControl.weightItemHint.code

                            switch(root.error) {
                            case WeightControlTypes.NotAdded: return "wceNotAddedHint"
                            case WeightControlTypes.NotScanned: return "wceNotScannedHint"
                            case WeightControlTypes.Overweight: return "wceOverweightHint"
                            case WeightControlTypes.Removed: return "wceRemovedHint"
                            case WeightControlTypes.NotStable: return "wceNotStableHint"
                            case WeightControlTypes.WrongWeight: return "wceWrongWeightHint"
                            case WeightControlTypes.NotScannedAbuse: return "wceNotScannedAbuseHint"
                            case WeightControlTypes.NotScannedPay: return "wceNotScannedPayHint"
                            case WeightControlTypes.RemovedHeft: return "wceRemovedHeftHint"
                            default: return ""
                            }
                        }

                        args: {
                            if (root.heft)
                                return [ WeightControl.weightItemName ]
                        }
                    }
                }
                Space { height: 250 }
                Loader {
                    Layout.alignment: Qt.AlignHCenter
                    property Component imageComponent: SvgImage {
                        property ImageData imageData: WeightControl.weightItemImage
                        source: imageData
                        scale: 2.5
                        width: 840
                    }
                    sourceComponent: root.heft && WeightControl.weightItemImage.valid ? imageComponent : null
                    source: {
                        if (root.heft && WeightControl.weightItemImage.valid)
                            return ""

                        switch(root.error) {
                        case WeightControlTypes.NotStable: return "UnstableImage.qml"
                        case WeightControlTypes.WrongWeight: return "WrongWeightImage.qml"
                        case WeightControlTypes.Overweight:
                        case WeightControlTypes.NotScannedAbuse:
                        case WeightControlTypes.NotScannedPay:
                        case WeightControlTypes.NotScanned: return "RemovingImage.qml"
                        case WeightControlTypes.NotAdded:
                        case WeightControlTypes.Removed:
                        case WeightControlTypes.RemovedHeft: return "AddingImage.qml"
                        default: return ""
                        }
                    }
                }
                Space { height: 70 }
                PositionList {
                    id: positionList
                    property real delegateHeight: 100
                    property int minPositionsCount: root.error === WeightControlTypes.RemovedHeft ? 4 : 5
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: 840
                    Layout.preferredHeight: delegateHeight * Math.min(model.count, minPositionsCount)
                                            + Math.min(model.count, minPositionsCount) + 1 // Разделители
                    visible: !root.heft && [ WeightControlTypes.WrongWeight, WeightControlTypes.NotAdded,
                        WeightControlTypes.NotScanned, WeightControlTypes.NotScannedPay,
                        WeightControlTypes.Removed, WeightControlTypes.NotScannedAbuse,
                        WeightControlTypes.RemovedHeft ].indexOf(root.error) >= 0
                    Component.onCompleted: {
                        checkModel.layoutChanged.connect(() => { scrollToEnd() })
                        scrollToEnd()
                    }
                    CheckModel { id: checkModel }
                    model: FilterModel {
                        id: model
                        sourceModel: checkModel
                        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
                    }
                    delegate: ColumnLayout {
                        width: positionList.width
                        height: positionList.delegateHeight
                        DashLineSeparator {
                            Layout.fillWidth: true; Layout.alignment: Qt.AlignTop; visible: !index
                            dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                        }
                        RowLayout {
                            Layout.fillWidth: true; Layout.alignment: Qt.AlignVCenter
                            Space { width: 10 }
                            SLabel {
                                Layout.fillWidth: true
                                Style.class: "weightControlPositionName"
                                text: model.name
                                elide: Text.ElideRight
                            }
                            Space { width: 20 }
                            SLabel {
                                leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                                Style.class: "weightControlPositionError"
                                Tr { code: model.wcStatus }
                                visible: text.length > 0
                            }
                            Space { width: 20 }
                            SLabel {
                                leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                                Style.class: "weightControlPositionQuantity"
                                text: "x" + model.quantity.str
                            }
                            Space { width: 10 }
                        }
                        DashLineSeparator {
                            Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom
                            dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                        }
                    }
                }


                Space { height: 50; visible: root.heft }
                SLabel {
                    Style.class: "weightControlHeftWeight"
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignVBottom
                    horizontalAlignment: Text.AlignHCenter
                    visible: root.heft

                    Tr {
                        id: weightTextTr
                        code: "weightControlWeighingWeight"
                        args: {
                            const weightDifference = Fract.fromGrams(WeightControl.currentWeight.value - WeightControl.previousWeight.value)
                            const greaterZero = weightDifference.isGreaterOrEqual(Fract.zero)
                            return [greaterZero ? weightDifference.str : Fract.zero.str]
                        }
                    }
                }
            }
        }

        Control {
            visible: root.heft || root.error === WeightControlTypes.RemovedHeft
            contentItem: RowLayout {
                id: buttonsLayout
                anchors {
                    right: parent.right
                    left: parent.left
                }

                property int buttonsWidth: width / 2 - spacing / 2

                ActionButton {
                    id: cancelWeighting
                    Style.class: "weightControlHeftCancel"
                    Layout.minimumWidth: parent.buttonsWidth
                    Layout.fillHeight: true
                    Layout.fillWidth: true

                    action: "WEIGHTCONTROL_CANCELWEIGHING"
                    icon: Style.parameter("icon.weightControlHeft.cancel")
                    Tr { code: "weightControlErrorCancel" }
                }
                ActionButton {
                    id: confirmWeighting
                    Style.class: "weightControlHeftConfirm"
                    enabled: WeightControl.canConfirm && !WeightControl.weightsAreEqual && WeightControl.currentWeight.isGreater(WeightControl.previousWeight)
                    Layout.minimumWidth: 0
                    Layout.fillHeight: true
                    Layout.fillWidth: true

                    action: "WEIGHTCONTROL_CONFIRMWEIGHTING"
                    Tr { code: "weightControlErrorConfirmWeighing" }
                }

                Behavior on spacing {
                    NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.weightControl.weighing", 250) }
                }
            }

            state: WeightControl.confirmWeighing && root.error !== WeightControlTypes.RemovedHeft ? "cancelAndConfirm" : "cancel"
            states: [
                State {
                    name: "cancel";
                    PropertyChanges { target: cancelWeighting; Layout.preferredWidth: buttonsLayout.width }
                    PropertyChanges { target: confirmWeighting; opacity: 0; Layout.preferredWidth: 0 }
                    PropertyChanges { target: buttonsLayout; spacing: 0; }
                },
                State {
                    name: "cancelAndConfirm";
                    PropertyChanges { target: cancelWeighting; Layout.preferredWidth: buttonsLayout.buttonsWidth }
                    PropertyChanges { target: confirmWeighting; opacity: 1; Layout.preferredWidth: buttonsLayout.buttonsWidth }
                    PropertyChanges { target: buttonsLayout; spacing: 20; }
                }
            ]
            transitions: [
                Transition { from: "cancel"; to: "cancelAndConfirm"
                    NumberAnimation {
                        target: cancelWeighting; property: "Layout.preferredWidth"; easing.type: Easing.InOutQuad
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                    NumberAnimation {
                        target: confirmWeighting; properties: "Layout.preferredWidth.opacity"; easing.type: Easing.InOutQuad
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                },
                Transition { from: "cancelAndConfirm"; to: "cancel"
                    NumberAnimation {
                        target: cancelWeighting; property: "Layout.preferredWidth"; easing.type: Easing.InOutQuad;
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                    NumberAnimation {
                        target: confirmWeighting; properties: "Layout.preferredWidth.opacity"; easing.type: Easing.InOutQuad;
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                }
            ]

            Layout.fillWidth: true
            Layout.preferredHeight: 90
            Layout.maximumHeight: 90
        }
    }
}
