import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes

import Check
import Core
import I18n

RowLayout {
    property alias model: cards
    property alias inputCardButton: inputCardButton
    property alias inputCouponButton: inputCouponButton
    property string animationStyleSection: ""

    property string scanCardTrCode: "loyaltyScanLoyaltyCard"
    property string cardBalanceTrCode: "loyaltyCardBalance"
    property string inputCouponTrCode: "loyaltyInputCoupon"

    CheckModel { id: checkModel }
    FilterModel {
        id: cards
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Card

        onLayoutChanged: () => cardItem.updateCard()
    }

    Layout.fillWidth: true
    spacing: 15

    ActionButton {
        id: inputCardButton
        Style.class: "ActionButton"
        action: "CHECK_INPUTCARD"

        ColumnLayout {
            id: addButton
            opacity: inputCardButton.contentItem == this
            visible: inputCardButton.contentItem == this

            SLabel {
                color: inputCardButton.color
                font: inputCardButton.font

                Tr { code: scanCardTrCode }

                Layout.alignment: Qt.AlignHCenter
            }

            Behavior on opacity {
                OpacityAnimator { duration: Style.animationDuration("transition" + animationStyleSection + ".cardInput", 500) }
            }
        }

        GridLayout {
            id: cardItem
            anchors.fill: parent

            flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight
            opacity: inputCardButton.contentItem == this
            visible: inputCardButton.contentItem == this

            // TODO: Устанавливать значение в зависимости от наличия встроенной рекламы
            property bool vertical: false
            property var cardIndex: cards.index(0, 0)
            property string cardName: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.Name) : ""
            property string cardBalance: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.Balance).str : ""
            property var hasBalance: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.HasBalance) : false
            function updateCard() {
                this.cardIndex = cards.index(0, 0)
            }

            RowLayout {
                spacing: 20

                SLabel {
                    color: inputCardButton.color
                    font: inputCardButton.font
                    text: cardItem.cardName

                    elide: Text.ElideRight
                    Layout.fillWidth: true
                }
                Control {
                    visible: cards.count > 1
                    leftPadding: 8
                    rightPadding: 8

                    contentItem: SLabel {
                        color: inputCardButton.background.color
                        font: inputCardButton.font
                        text: "+" + (cards.count - 1)
                    }

                    background: Rectangle {
                        color: inputCardButton.color
                        radius: height / 2
                    }
                }

                Layout.leftMargin: 30
                Layout.rightMargin: balanceLabel.visible ? 0 :30
                Layout.topMargin: 20
                Layout.bottomMargin: parent.vertical ? 0 : 20
            }

            SLabel {
                id: balanceLabel
                color: inputCardButton.color
                font: inputCardButton.font
                visible: cardItem.hasBalance

                Tr { code: cardBalanceTrCode; args: [ cardItem.cardBalance ] }

                Layout.alignment: parent.vertical ? Qt.AlignLeft : Qt.AlignRight
                Layout.leftMargin: 30
                Layout.topMargin: parent.vertical ? 10 : 20
                Layout.rightMargin: 30
                Layout.bottomMargin: 20
            }

            Behavior on opacity {
                OpacityAnimator { duration: Style.animationDuration("transition" + animationStyleSection + ".cardInput", 500) }
            }

            Component.onCompleted: () => updateCard()
        }

        contentItem: cards.count === 0 ? addButton : cardItem

        Layout.fillWidth: !inputCouponButton.visible
        Layout.minimumHeight: 80
        implicitWidth: parent.width * 2 / 3 - parent.spacing * 2 / 3

        Behavior on height {
            NumberAnimation { duration: Style.animationDuration("transition" + animationStyleSection + ".cardInput", 100) }
        }
    }

    ActionButton {
        id: inputCouponButton
        Style.class: "ActionButton"
        action: "CHECK_INPUTCOUPON"
        visible: false

        Tr { code: inputCouponTrCode }

        implicitWidth: parent.width / 3 - parent.spacing / 3
        Layout.fillWidth: true
        Layout.minimumHeight: 80
    }
}
